/****************************************************************************
**
** Copyright (C) 2013-2018 Esri <contracts@esri.com>
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtLocation module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef GEOTILEFETCHERESRI_H
#define GEOTILEFETCHERESRI_H

#include <QtLocation/private/qgeotilefetcher_p.h>

QT_BEGIN_NAMESPACE

class QGeoTiledMappingManagerEngine;
class QNetworkAccessManager;

class GeoTileFetcherEsri : public QGeoTileFetcher
{
    Q_OBJECT

public:
    explicit GeoTileFetcherEsri(QGeoTiledMappingManagerEngine *parent);

    inline const QByteArray &userAgent() const;
    inline void setUserAgent(const QByteArray &userAgent);

    inline const QString &token() const;
    inline void setToken(const QString &token);

private:
    QGeoTiledMapReply *getTileImage(const QGeoTileSpec &spec) override;

    QNetworkAccessManager *m_networkManager;
    QByteArray m_userAgent;
    QString m_token;
};

inline const QByteArray &GeoTileFetcherEsri::userAgent() const
{
    return m_userAgent;
}

inline void GeoTileFetcherEsri::setUserAgent(const QByteArray &userAgent)
{
    m_userAgent = userAgent;
}

inline const QString &GeoTileFetcherEsri::token() const
{
    return m_token;
}

inline void GeoTileFetcherEsri::setToken(const QString &token)
{
    m_token = token;
}

QT_END_NAMESPACE

#endif // GEOTILEFETCHERESRI_H
